from Pyblio import Config

Config.define ('bibtex/strict',
               """ A boolean indicating the strictness of the parsing """)

Config.set ('bibtex/strict', 0)


